* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Step 2: Collect and Maintain Data](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment-enrich-data)
  * Configure Data Quality Controls
